<?php
$lang['setup_flat_urls'] = 'Nastavenie  priamych URL';
$lang['install_timezone'] = 'Niektor&eacute; servery bežiace na php 5.3 maju sle nastaven&eacute; časov&eacute; p&aacute;smo .  Prośim vyberte časov&uacute; z&oacute;nu zo zoznamu niž&scaron;ie.  Ak nechcete vyberať, vyberte voľbu &quot;Žiadne&quot;';
$lang['timezone'] = 'Časov&aacute; z&oacute;na';
$lang['none'] = 'Žiadne';
$lang['test_error_estrict'] = 'Test  error_reporting a vypnutie E_STRICT';
$lang['test_estrict_failed'] = 'E_STRICT je zapnut&yacute;';
$lang['info_estrict_failed'] = 'Niektor&eacute; knižnice CMSMS nebud&uacute; pracovať spr&aacute;vne s E_STRICT. Pros&iacute;m vypnute toto nastavenie pred pokračovan&iacute;m';
$lang['test_error_edeprecated'] = 'Test  error_reporting a vypnutie E_DEPRECATED';
$lang['test_edeprecated_failed'] = 'E_DEPRECATED je zapnut&yacute;';
$lang['info_edeprecated_failed'] = 'Ak E_DEPRECATED je zapnut&eacute;, už&iacute;uvatelia uvidia veľa chybov&yacute;ch hl&aacute;sen&iacute;';
$lang['invalidemail'] = 'E-mailov&aacute; adresa je nespr&aacute;vna';
$lang['empty_query'] = 'Pr&aacute;zdny dotaz?? %s';
$lang['no_db_driver'] = 'Neboli n&aacute;jdene  žiadne kompatibiln&eacute; ovl&aacute;dače pre datab&aacute;zu';
$lang['test_check_output_buffering'] = 'Kontrolujem output buffering';
$lang['test_check_output_buffering_failed'] = 'Output buffering je vypnut&yacute;. Pravdepodobne nebude můcř využ&iacute;vař niektor&eacute; z funkcional&iacute;t, ktor&eacute; vyžad&uacute; Output buffering zapnut&yacute;';
$lang['phpinfo'] = 'Zobraziť inform&aacute;cie o PHP';
$lang['mod_security'] = 'Apache m&oacute;d ochrany';
$lang['test_check_tempnam'] = 'Kontrola funkcie tempnam';
$lang['test_check_db_drivers'] = 'Ovl&aacute;dače datab&aacute;zy';
$lang['test_check_db_drivers_failed'] = 'Neboli n&aacute;jden&eacute; ovl&aacute;dače datab&aacute;zy';
$lang['test_check_register_globals'] = 'Kontrola PHP register globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals je aktivovan&aacute;. Z bezpečnostn&yacute;ch d&ocirc;vodov požiadajte o vypnutie tohto nastavenia.';
$lang['test_check_disable_functions'] = 'Kontrola vypnut&yacute;ch funkci&iacute; PHP';
$lang['test_check_disable_functions_failed'] = 'Varovanie: zoznam funkc&iacute; vypnut&yacute;ch na vačom serveri';
$lang['install_admin_db_port'] = 'Port datab&aacute;zy';
$lang['install_admin_db_port_info'] = 'V pr&iacute;pade že neviete, nechajte pr&aacute;zdne';
$lang['install_admin_db_socket'] = 'Socket datab&aacute;zy';
$lang['install_admin_db_socket_info'] = 'NEPODPOROVAN&Eacute;';
$lang['install_admin_frontendlang'] = 'Prednastaven&yacute; jazyk pre web (frontend). Toto nastavuje spr&aacute;vanie pre prednastaven&eacute; hodnoty d&aacute;tumy a podobne.';
$lang['install_default_encoding'] = 'Prednastaven&eacute; k&oacute;dovanie vo v&auml;č&scaron;ine pr&iacute;padov b&yacute;va utf-8.';
$lang['installer_done'] = '[ok]';
$lang['installer_failed'] = '[s chybou]';
$lang['create_permission'] = 'Vytv&aacute;ram pr&iacute;stupov&eacute; pr&aacute;va ...';
$lang['add_column_sql'] = 'Prid&aacute;vam stĺpec do tabuľky %s...';
$lang['update_table_sql'] = 'Aktualizuje tabuľku %s ...';
$lang['installing_module'] = 'In&scaron;talujem modul %s ...';
$lang['updating_schema_version'] = 'Aktualizujem sch&eacute;mu na verziu %s ...';
$lang['upgrade_config'] = 'Aktualizujem konfiguračn&yacute; s&uacute;bor config.php';
$lang['upgrade_config_info'] = 'configuračn&yacute; s&uacute;bor aktualizovan&yacute;';
$lang['upgrade_failed_again'] = 'Pri aktualiz&aacute;cii do&scaron;lo k chyb&aacute;m. Pros&iacute;m vyrie&scaron;te probl&eacute;my a znovu skontrolujte.';
$lang['upgrade_cache_dirs'] = 'Vypr&aacute;zdňujem ke&scaron; adres&aacute;r';
$lang['cannot_clean_cache_dirs'] = 'Nie je možn&eacute; vypr&aacute;zdniť ke&scaron; adres&aacute;re';
$lang['upgrade_schema'] = 'Aktualizovan&aacute; sch&eacute;m';
$lang['need_upgrade_schema'] = 'CMS potrebuje aktualizovať.<br />Aktu&aacute;lne použ&iacute;vate sch&eacute;mu %s a potrebujete aktualizovať na verziu %s';
$lang['schema_ok'] = 'Datab&aacute;za aktualizovan&aacute;.  Použ&iacute;vate sch&eacute;mu verzie %s';
$lang['noneed_upgrade_schema'] = 'Datab&aacute;za aktualizovan&aacute;.  Použ&iacute;vate sch&eacute;mu verzie%s';
$lang['upgrade_modules'] = 'Aktualizujem moduly';
$lang['noneed_upgrade_modules'] = 'Moduly jadra aktualizovan&eacute;';
$lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
$lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
$lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
$lang['upgrade_complete'] = 'Aktualiz&aacute;cia kompletn&aacute;';
$lang['upgrade_end'] = 'Aktualiz&aacute;cia kompletn&aacute;. Pros&iacute;m prejdine %s na va&scaron;u str&aacute;nku alebo %s.';
$lang['here'] = 'kliknut&iacute;m';
$lang['go_to_admin'] = 'prejdite do v&aacute;&scaron;ej administr&aacute;cie.';
$lang['errorfilenot'] = 'S&uacute;bor nen&aacute;jden&yacute;!';
$lang['errorfilenotwritable'] = 'S&uacute;bor nie je zapisovateľn&yacute;!';
$lang['nofiles'] = 'Tento zdroj neexistuje!';
$lang['is_directory'] = 'Tento zdroj je adres&aacute;r!';
$lang['is_readable_false'] = 'Tento zdroj nem&aacute; pr&aacute;va na č&iacute;tanie!';
$lang['checksum_match'] = 'Porovnanie kontroln&yacute;ch s&uacute;čtov!';
$lang['checksum_not_match'] = 'Bez kontroly kontroln&yacute;ch s&uacute;čtov!';
$lang['not_checksum'] = 'Neviem skontrolovať kontroln&eacute; s&uacute;čty!';
$lang['format_datetime'] = '%c ';
$lang['upload_err_ini_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v upload_max_filesize v php.ini!';
$lang['upload_err_form_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v  MAX_FILE_SIZE, ktor&yacute; je zadan&yacute; v html vo formul&aacute;ri.';
$lang['upload_err_partial'] = 'Nahr&aacute;van&yacute; s&uacute;bor bol nahran&yacute; len čiastočne.';
$lang['upload_err_no_file'] = 'S&uacute;bor nenahran&yacute;.';
$lang['upload_err_no_tmp_dir'] = 'Ch&yacute;ba dočasn&yacute; adres&aacute;r (temp).';
$lang['upload_err_cant_write'] = 'Chyba pri zapisovan&iacute; s&uacute;boru na disk';
$lang['upload_err_extension'] = 'Nahr&aacute;vanie s&uacute;boru zastaven&eacute;.';
$lang['upload_err_empty'] = 'S&uacute;bor m&aacute; nulov&uacute; veľkosť';
$lang['upload_err_unknown'] = 'Nezn&aacute;my probl&eacute;m pri nahr&aacute;van&iacute; s&uacute;boru';
$lang['function_file_uploads_off'] = 'file_uploads je vypnut&yacute; vo va&scaron;ej konfigur&aacute;cii PHP';
$lang['upload_file_no_readable'] = 'Nahr&aacute;van&yacute; s&uacute;bor nem&aacute; pr&aacute;va pre č&iacute;tanie!';
$lang['upload_file_multiple'] = 'Viacn&aacute;sobn&eacute; nahr&aacute;vanie nie je povolen&eacute;!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes pre Get/Post/Cookie oper&aacute;cie';
$lang['test_check_magic_quotes_gpc_failed'] = 'V pr&iacute;pade, že je zapnut&eacute; magic_quotes, vśetky &uacute;vodzovky a sp&auml;tn&eacute; lom&iacute;tka s&uacute; automatick&yacute; esapovan&eacute; sp&auml;tn&yacute;m lom&iacute;tkom, čo m&ocirc;že sp&ocirc;sobiť nemal&eacute; probl&eacute;my v CMS.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes bež&iacute;';
$lang['test_check_magic_quotes_runtime_failed'] = 'V pr&iacute;pade, že je zapnut&eacute; magic_quotes, vśetky &uacute;vodzovky a sp&auml;tn&eacute; lom&iacute;tka s&uacute; automatick&yacute; esapovan&eacute; sp&auml;tn&yacute;m lom&iacute;tkom, čo m&ocirc;že sp&ocirc;sobiť nemal&eacute; probl&eacute;my v CMS.';
$lang['install_admin_checksum'] = 'Kontrolujem in&scaron;tal&aacute;ciu';
$lang['upgrade_admin_checksum'] = 'Kontroluje syst&eacute;m pre aktualiz&aacute;ciu';
$lang['checksum'] = 'Test kontroln&yacute;ch s&uacute;čtov';
$lang['checksum_file'] = 'S&uacute;bor kontroln&yacute;ch s&uacute;čtov';
$lang['install_test_checksum'] = 'M&ocirc;žete porovnať s&uacute;bory v&aacute;&scaron;ho CMS s kontroln&yacute;mi s&uacute;čtami in&scaron;talačky.  M&ocirc;že v&aacute;m pom&ocirc;cť pri hľadan&iacute; probl&eacute;mov pri nekomplenom nahrat&iacute; CMS atď.';
$lang['checksum_passed'] = 'V&scaron;etky kontroln&eacute; s&uacute;čty s&uacute; v poriadku!';
$lang['checksum_failed'] = 'Kontrola kontroln&yacute;ch s&uacute;čtov s chybami. Preč&iacute;tajte si pomocn&iacute;ka pre viac inform&aacute;cii';
$lang['test_check_open_basedir'] = 'Kontrola PHP Open Basedir';
$lang['test_check_open_basedir_failed'] = 'Open basedir obmedzenia s&uacute; nastaven&eacute;. M&ocirc;žete mať probl&eacute;m s niektor&yacute;m vybran&yacute;mi funkcionalitami.';
$lang['unlimited'] = 'Neobmedzene';
$lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable session by cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['install_warn_db_createtables'] = 'Zvyčajne b&yacute;va toto pole vždy kontrolovan&eacute;.  Buďte  opatrn&yacute; pri vypnut&iacute;';
$lang['install_admin_tablesnotcreated'] = 'Process complete.  The installation process has completed, at your request database tables were not created.  However, the config file has been reset and all pre-installation tests have passed.  Thank you, and here is your';
$lang['info_create_dir_and_file'] = 'The HTTP Process owner cannot create a file inside a directory that it owns. This probably means that safe mode is enabled in some way.  Many functions inside CMS made simple will not operate properly without this ability. Continuing is not possible.';
$lang['test_create_dir_and_file'] = 'Kontrola, či  httpd process  m&ocirc;že vytvoriť s&uacute;bor vo vytvorenom adres&aacute;ri. ';
$lang['cms_site'] = 'CMS str&aacute;nka';
$lang['or_greater'] = 'Alebo v&auml;č&scaron;&iacute;';
$lang['sitename'] = 'N&aacute;zov str&aacute;nky';
$lang['warning_safe_mode'] = '<strong><em>Varovanie:</em></strong> PHP Safe m&oacute;d zapnut&yacute;.  Toto m&ocirc;že sp&ocirc;sobiť probl&eacute;my pri nahr&aacute;van&iacute; s&uacute;borov cez administr&aacute;ciu (obrazky, s&uacute;bory, t&eacute;my, XML moduly) atď. Požiadajte svojho administr&aacute;tora o vypnutie tejto direktivy.';
$lang['test'] = 'Test ';
$lang['results'] = 'V&yacute;sledky';
$lang['untested'] = 'Netestovan&eacute;';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['permissions'] = 'Pr&aacute;va';
$lang['off'] = 'z';
$lang['on'] = 'Na';
$lang['permission_information'] = 'Inform&aacute;cie o pr&aacute;vach';
$lang['server_os'] = 'Operačn&yacute; syst&eacute;m servera';
$lang['server_api'] = 'Api server';
$lang['server_software'] = 'Server software';
$lang['server_information'] = 'Inform&aacute;cie o serveri';
$lang['session_save_path'] = 'Ukladanie session (Session Save Path)';
$lang['max_execution_time'] = 'Čas vykon&aacute;vania skriptu (Maximum Execution Time)';
$lang['gd_version'] = 'Verzia knižnice GD ';
$lang['upload_max_filesize'] = 'Maxim&aacute;lna veľkosť s&uacute;bora pre nahr&aacute;vanie (max upload size)';
$lang['post_max_size'] = 'Maxim&aacute;lna veľkosť s&uacute;bora pre odoslanie met&oacute;dov (max post size)';
$lang['memory_limit'] = 'Limit pam&auml;te PHP ';
$lang['server_db_type'] = 'Datab&aacute;za';
$lang['server_db_version'] = 'Verzia datab&aacute;zy';
$lang['phpversion'] = 'Aktu&aacute;lna verzia PHP ';
$lang['safe_mode'] = 'PHP Safe m&oacute;d';
$lang['php_information'] = 'PHP info';
$lang['cms_install_information'] = 'CMS info in&scaron;tal&aacute;cie';
$lang['cms_version'] = 'Vezia CMS';
$lang['systeminfo_copy_paste'] = 'Pros&iacute;m, skop&iacute;rujte vyznačen&yacute; text a vložte do f&oacute;ra v pr&iacute;pade rie&scaron;enia probl&eacute;mov';
$lang['help_systeminformation'] = 'The information displayed below is collected from a variety of locations, and summarized here so that you may be able to conveniently find some of the information required when trying to diagnose a problem or request help with your CMS Made Simple installation.';
$lang['systeminfo'] = 'Syst&eacute;mov&eacute; inform&aacute;cie';
$lang['systeminfodescription'] = 'Zobraz&iacute; vybran&eacute; inform&aacute;cie o va&scaron;om syst&eacute;me, čo v&aacute;m m&ocirc;že uľahčiť pri diagnostike probl&eacute;mov.';
$lang['error'] = 'Chyba';
$lang['new_version_available'] = '<em>Pozn&aacute;mka:</em> Nov&aacute; verzia CMS Made Simple je dostupn&aacute;. Pros&iacute;m, upozornite na to administr&aacute;tora webu';
$lang['info_urlcheckversion'] = 'Vyplňte  &quot;none&quot; a kontrola neprebehne.<br/> Nechajte pr&aacute;zdne a použije sa prednastaven&aacute; URL.';
$lang['urlcheckversion'] = 'Kontrola aktu&aacute;lnej verzie CMS pomocou nasleduj&uacute;cej linky';
$lang['read'] = 'Č&iacute;tať';
$lang['write'] = 'Zapisovať';
$lang['execute'] = 'Vykon&aacute;vať';
$lang['group'] = 'Skupina';
$lang['other'] = 'Ostatn&eacute;';
$lang['global_umask'] = 'Maska pri vytv&aacute;ran&iacute; s&uacute;borov (umask)';
$lang['errorcantcreatefile'] = 'Nemožem vytvoriť s&uacute;bor (probl&eacute;m s pr&aacute;vami?)';
$lang['add'] = 'Pridať';
$lang['about'] = 'O';
$lang['action'] = 'Akcia';
$lang['actionstatus'] = 'Akcia/Stav';
$lang['active'] = 'Akt&iacute;vny';
$lang['cantremove'] = 'Nie je možn&eacute; odstr&aacute;niť';
$lang['changepermissions'] = 'Zmeniť pr&aacute;va';
$lang['changepermissionsconfirm'] = 'UPOZORNENIE\n\nThis action will attempt to ensure that all of the files making up the module are writable by the web server.\nAre you sure you want to continue?';
$lang['success'] = '&Uacute;spech';
$lang['advanced'] = 'Roz&scaron;&iacute;ren&eacute;';
$lang['back'] = 'Nasp&auml;ť do menu';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['cantchmodfiles'] = 'Nie je možn&eacute; zmeniť pr&aacute;va niektor&yacute;m s&uacute;borom';
$lang['cantremovefiles'] = 'Probl&eacute;m pri odstr&aacute;nen&iacute; s&uacute;borov (pr&aacute;va?)';
$lang['create'] = 'Vytvoriť';
$lang['database'] = 'Datab&aacute;za';
$lang['databaseprefix'] = 'Prefix';
$lang['databasetype'] = 'Typ datab&aacute;ze';
$lang['date'] = 'D&aacute;tum';
$lang['default'] = 'Predvolen&eacute;';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['deleteconfirm'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť - %s - ?';
$lang['description'] = 'Popis';
$lang['directoryexists'] = 'Adres&aacute;r už existuje';
$lang['down'] = 'Niž&scaron;ie';
$lang['edit'] = 'Upraviť';
$lang['email'] = 'E-mail adresa';
$lang['errordeletingfile'] = 'Nem&ocirc;žem odstr&aacute;niť s&uacute;bor. Probl&eacute;m s pr&aacute;vami?';
$lang['errordirectorynotwritable'] = 'Nem&aacute;te pr&aacute;va na z&aacute;pis do adres&aacute;ra. Toto može s&uacute;visieť s nastaven&iacute;m pr&aacute;v a vlastn&iacute;kov s&uacute;borov,  alebo s nastaven&iacute;m bezpečnostn&eacute;ho m&oacute;du (Safe mode).';
$lang['cachenotwritable'] = 'Adres&aacute;r pre ke&scaron; (cache) nie je zapisovateľny, funkcia na vyčistenie cache nebude fungovať. Pros&iacute;m zabezpečte pr&aacute;va pre č&iacute;tanie/z&aacute;pis/vykon&aacute;vanie/ pre adres&aacute;r tmp/cache (chmod 777).  Takisto si overte vypnutie bezpečnostn&eacute;ho m&oacute;du (Safe mode).';
$lang['modulesnotwritable'] = 'Adres&aacute;r pre moduly nie je zapisovateľn&yacute;,v  pr&iacute;pade že budete chcieť in&scaron;talovať moduly nahrat&iacute;m XML s&uacute;boru, mus&iacute;te zabezpečiť pre tento adres&aacute;r plne pr&aacute;va (chmod 777), vr&aacute;tane vypnut&eacute;ho bezp. m&oacute;du (Safe mode).';
$lang['false'] = 'Nastaviť false';
$lang['settrue'] = 'Nastaviť True';
$lang['filename'] = 'N&aacute;zov s&uacute;boru';
$lang['filesize'] = 'Veľkosť s&uacute;boru';
$lang['help'] = 'Pomoc';
$lang['language'] = 'Jazyk';
$lang['lastname'] = 'Priezvisko';
$lang['name'] = 'Meno';
$lang['password'] = 'Heslo';
$lang['passwordagain'] = 'Heslo (znova)';
$lang['remove'] = 'Odstr&aacute;niť';
$lang['saveconfig'] = 'Uložiť nastavenia';
$lang['true'] = '&Aacute;no';
$lang['setfalse'] = 'Nastaviť false';
$lang['type'] = 'Typ';
$lang['typenotvalid'] = 'Typ nie je validn&yacute;';
$lang['unknown'] = 'Nezn&aacute;my';
$lang['user'] = 'Už&iacute;vateľ';
$lang['userdefinedtags'] = 'Použivateľsk&eacute; t&aacute;gy (UDT)';
$lang['usermanagement'] = 'Spr&aacute;va použ&iacute;vateľov';
$lang['username'] = 'Už&iacute;vateľks&eacute; meno';
$lang['usernameincorrect'] = 'Už&iacute;vateľsk&eacute; meno alebo heslo nie s&uacute; spr&aacute;vne';
$lang['version'] = 'Verzia';
$lang['install_title'] = 'In&scaron;tal&aacute;cia syst&eacute;mu CMS Made Simple (step %s)';
$lang['install_system'] = 'In&scaron;tal&aacute;cia syst&eacute;mu';
$lang['install_thanks'] = 'Vďaka za nain&scaron;talovanie CMS Made Simple';
$lang['upgrade_title'] = 'CMS Made Simple aktualiz&aacute;cia (krok %s)';
$lang['upgrade_system'] = 'Update syst&eacute;mu';
$lang['upgrade_thanks'] = 'Ďakujeme za aktualiz&aacute;ciu CMS Made simple na verziu';
$lang['install_please_read'] = 'Pros&iacute;m, preč&iacute;tajte si <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">dokument&aacute;ciu k in&scaron;tal&aacute;cii</a> k CMS Made Simple.';
$lang['install_checking'] = 'Kontrola pr&aacute;v a nastaven&iacute; PHP';
$lang['install_test'] = 'Test ';
$lang['install_result'] = 'V&yacute;sledky';
$lang['install_required_settings'] = 'Vyžadovan&eacute; nastavenia';
$lang['install_recommended_settings'] = 'Doporučen&eacute; nastavenia';
$lang['install_you_have'] = 'Vy m&aacute;te';
$lang['install_legend'] = 'Legenda';
$lang['install_symbol'] = 'Znak';
$lang['install_definition'] = 'Defin&iacute;cia';
$lang['install_value_passed'] = 'Test v poriadku';
$lang['install_value_failed'] = 'Test s chybami/chybou';
$lang['install_error_fragment'] = 'Inform&aacute;cie o probl&eacute;moch pri in&scaron;tal&aacute;cii';
$lang['install_value_required'] = 'Nastavenia niž&scaron;ie vyžaduj&uacute; minim&aacute;lne hodnoty';
$lang['install_value_recommended'] = 'Nastavenie je v&auml;č&scaron;ie ako požadovan&aacute; hodnota, ale niž&scaron;ia ako doporučen&aacute; hodnota.<br />  Vybran&eacute; &scaron;peci&aacute;lne funkcionality m&ocirc;žu byť nedostupn&eacute;.';
$lang['install_value_exceed'] = 'Nastavenie splňuje alebo prekračuje požadovan&eacute; hodnoty.';
$lang['install_test_failed'] = 'Testovan&eacute; vlasnosti s chybou. M&ocirc;žete v&scaron;ak pokra&scaron;ovať v in&scaron;tal&aacute;cii, av&scaron;ak niektor&eacute; funkcionality nemusia fungovať spr&aacute;vne.  Pros&iacute;m sk&uacute;ste vyrie&scaron;iť ot&aacute;zne nastavenia a znova skontrolujte stav.  Pr&iacute;padne pokračujte v in&scaron;tal&aacute;cii.';
$lang['install_test_passed'] = 'V&scaron;etky testovan&eacute; vlasnosti v poriadku (aspoň na minim&aacute;lnej &uacute;rovni. Pros&iacute;m pokračujte';
$lang['install_failed_again'] = 'V&scaron;etky testovan&eacute; vlasnosti  nie s&uacute; v poriadku. Pros&iacute;m sk&uacute;ste vyznačen&eacute; problm&eacute;my vyrie&scaron;iť a skontrolujte stav znova.';
$lang['install_try_again'] = 'Vysk&uacute;&scaron;ať znovu';
$lang['install_continue'] = 'Pokračovať';
$lang['failure'] = 'Zlyhanie';
$lang['caution'] = 'Opatrne';
$lang['install_admin_umask'] = 'Test s&uacute;boru vytvorenia masky';
$lang['install_test_umask'] = 'Pros&iacute;m kliknite na tlač&iacute;tko pre kontrolu  ..............................';
$lang['test_umask_text'] = 'umask  is a function in POSIX environments which affects the default file system mode for newly created files and directories of the current process. It controls which of the file permissions will not be set for any newly created file.';
$lang['test_check_umask'] = 'V&yacute;sledok testu na s&uacute;bor vytvoren&yacute; v';
$lang['test_umask_not_given'] = 'Umask nebol pridan&yacute;';
$lang['test_check_umask_failed'] = 'Test umask zlyhal';
$lang['test_username_not_given'] = 'Už&iacute;vateľsk&eacute; meno nebolo zadan&eacute;!';
$lang['test_username_illegal'] = 'Už&iacute;vateľsk&eacute; meno obsahuje nepovolen&eacute; znaky!';
$lang['test_not_both_passwd'] = 'Neboli zadan&eacute; ob&eacute; hesla!';
$lang['test_passwd_not_match'] = 'Hesla sa nezhoduj&uacute;!';
$lang['test_email_accountinfo'] = 'E-mail nebol zadan&yacute;!';
$lang['test_database_prefix'] = 'Prefix pre tabuľky datab&aacute;zy obsahuje nepovolen&eacute; znaky';
$lang['test_no_dbms'] = 'Žiadna vybran&aacute; dbms!';
$lang['test_could_not_connect_db'] = 'Nem&ocirc;žem sa pripojiť k datab&aacute;ze.  Skontrolujte svoje pr&iacute;stupov&eacute; meno a heslo do datab&aacute;zy.';
$lang['test_could_not_drop_table'] = 'Nem&ocirc;žem odstr&aacute;niť tabuľku. Overte si svoje pr&aacute;va pre pr&aacute;cu s t&aacute;buľkami v datab&aacute;ze.';
$lang['test_could_not_create_table'] = 'Nem&ocirc;žem vytvoriť tabuľku. Overte si svoje pr&aacute;va pre pr&aacute;cu s t&aacute;buľkami v datab&aacute;ze.';
$lang['test_check_php'] = 'Kontrola pre verziu PHP %s+';
$lang['test_min_recommend'] = '(minimum %s, doporučovan&eacute; %s alebo vy&scaron;ie)';
$lang['test_min_recommend_plus'] = '(min %s, doporučovan&eacute; %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple vyžaduje pre svoj chod php 4.3 alebo vy&scaron;&scaron;iu (vy m&aacute;te %s), ale PHP %s alebo vy&scaron;ia je doporučovan&aacute; maxim&aacute;lnu kompatibilitu s modulmy/roz&scaron;&iacute;reniami tret&iacute;ch str&aacute;n';
$lang['test_check_md5_func'] = 'Kontrola pre funkciu md5 ';
$lang['test_check_safe_mode'] = 'Kontrola pre safe m&oacute;d';
$lang['test_check_safe_mode_failed'] = 'Zapnut&yacute; PHP safe m&oacute;d  m&ocirc;že sp&ocirc;sobiť nejak&eacute; probl&eacute;my s nahr&aacute;van&iacute;tm s&uacute;borov a spr&aacute;vnym behom niektor&yacute;ch funkcional&iacute;t. V&scaron;etko z&aacute;vis&yacute; ako striktn&eacute; je nastaven&yacute; server pri zapnutom Safe m&oacute;de.';
$lang['test_check_tokenizer'] = 'Kontroluje tokenizer funkcie';
$lang['test_check_tokenizer_failed'] = 'Bielu str&aacute;nku m&ocirc;že sp&ocirc;sobovať vypnut&aacute; funkcia Tokenizer. Požiadajte administr&aacute;tora o jej zapnutie';
$lang['test_check_gd'] = 'Kontrola knižnice GD';
$lang['test_check_gd_failed'] = 'GD knižnica je nevyhnutn&aacute; pre niektor&eacute; moduly a funkcionality';
$lang['test_check_write'] = 'Kontrola pr&aacute;v pre zapisovanie na';
$lang['test_may_not_exist'] = 'S&uacute;bor možno e&scaron;te neexistujte. Ak tomu tak je, m&ocirc;žete vytvoriť pr&aacute;zdny s&uacute;bor s t&yacute;mto menom. Takisto sa uistite, že m&aacute; nastaven&eacute; pr&aacute;va na č&iacute;tanie. ';
$lang['could_not_retrieve_a_value'] = 'Nepodarilo sa z&iacute;skať hodnotu';
$lang['displaying_the_value_originally'] = '<br />Zobrazovanie nastaven&iacute; z configuračn&eacute;ho s&uacute;boru (nemus&iacute; byť presn&eacute;)';
$lang['test_check_xml_func'] = 'Kontrola z&aacute;kladne podpory pre XML (expat)';
$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
$lang['test_remote_url'] = 'Test vzdialenej URL';
$lang['test_remote_url_failed'] = 'Pravdepodobne nebude m&ocirc;žno otvoriť s&uacute;bor cez vzdialen&yacute; web server. ';
$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
$lang['remote_connection_timeout'] = 'Vypr&scaron;al časov&yacute; limit pripojenia!';
$lang['search_string_find'] = 'Pripojenie v poriadku!';
$lang['connection_failed'] = 'Pripojenie zlyhalo!';
$lang['remote_response_ok'] = 'Vzdialen&aacute; odpoveď: ok!';
$lang['remote_response_404'] = 'Vzdialen&aacute; odpoved: nen&aacute;jedn&eacute;!';
$lang['remote_response_error'] = 'Vzdialen&aacute; odpoveď: chyba!';
$lang['test_check_file_upload'] = 'Kontroluje nahr&aacute;vanie s&uacute;borov';
$lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
$lang['test_check_memory'] = 'Kontrolujem PHP limit pam&auml;te';
$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
$lang['test_check_time_limit'] = 'Kontrolujem PHP časov&yacute; limit';
$lang['test_check_time_limit_failed'] = 'Počet sek&uacute;nd pre beh skriptu. Pokiaľ skript presiahne t&uacute;to hodnotu zobraz&iacute; sa chybov&eacute; hl&aacute;senie';
$lang['test_check_post_max'] = 'Kontrola max post size';
$lang['test_check_post_max_failed'] = 'Pravdepodobne nebudete m&ocirc;cť nahr&aacute;vať v&auml;č&scaron;ie s&uacute;bory. Pros&iacute;m berte na vedomie tento fakt.';
$lang['test_check_upload_max'] = 'Kontrola max upload file size';
$lang['test_check_upload_max_failed'] = 'Pravdepodobne nebudete m&ocirc;cť nahr&aacute;vať v&auml;č&scaron;ie s&uacute;bory. Majte napam&auml;ti toto obmedzenie pri probl&eacute;moch pri nahr&aacute;van&iacute;';
$lang['test_check_writable'] = 'Kontrola pr&aacute;v pre zapisovanie pre %s';
$lang['test_check_upload_failed'] = 'Adres&aacute;r /uploads/ nie je zapisovateľny. M&ocirc;žete pokračovať v in&scaron;tal&aacute;cii, ale nebudete m&ocirc;cť nahr&aacute;vať s&uacute;bory cez administračn&eacute; rozhranie.';
$lang['test_check_images_failed'] = 'Adres&aacute;r /uploads/images/ nie je zapisovateľn&yacute;. M&ocirc;žete pokračovať v in&scaron;tal&aacute;cii, ale nebudete m&ocirc;cť nahr&aacute;vať obr&aacute;zky cez administračn&eacute; rozhranie.';
$lang['test_check_modules_failed'] = 'Adres&aacute;r /modules/ nie je zapisovateľn&yacute;. M&ocirc;žete pokračovať v in&scaron;tal&aacute;cii, ale nebudete m&ocirc;cť nahr&aacute;vať moduly priamo cez administračn&eacute; rozhranie.';
$lang['test_check_file_get_contents'] = 'Kontrola pre podporu funkcie file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'Pravdepodobne nebudete m&ocirc;cť využ&iacute;vať funkcionality, ktor&eacute; použ&iacute;vaj&uacute; t&uacute;to funkciu';
$lang['test_check_session_save_path'] = 'Kontrola na m&ocirc;žnosť zapisovania do session.save_path';
$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
$lang['test_check_session_save_path_failed'] = 'Your session.save_path is &quot;%s&quot;. Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
$lang['test_check_ini_set'] = 'Kontrola, na možn&eacute; použ&iacute;vanie ini_set';
$lang['test_check_ini_set_failed'] = 'Aj keď možnosť meniť nastavenia v s&uacute;bore php.ini nie je povinn&aacute;, niektor&eacute; roz&scaron;&iacute;renia m&ocirc;žu tieto nastavenia vyžadovať (napr. možnosť nahr&aacute;vať v&auml;č&scaron;ie s&uacute;bory). Tento test m&ocirc;že hl&aacute;siť chybu v pr&iacute;pade, že je zapnut&eacute; safe_mode v php.';
$lang['install_admin_header'] = 'Inform&aacute;cie o administr&aacute;torskom &uacute;čte';
$lang['install_admin_info'] = 'Vyberte už&iacute;vateľsk&eacute; meno, heslo a e-mailovou adresu pre Va&scaron; administr&aacute;torsky &uacute;čet. Tieto &uacute;daje si pros&iacute;m zaznačte, bez nich sa nedostanete do administr&aacute;cie CMS made simple.';
$lang['install_admin_email'] = 'E-mailov&aacute; adresa';
$lang['install_admin_email_info'] = 'Inform&aacute;cie o &uacute;čte na e-mail';
$lang['install_admin_email_note'] = '<strong>Pozn&aacute;mka:</strong> Tato funkce využ&iacute;va funkcii mail v php. Pokiaľ neobdrž&iacute;te testovac&iacute; tento e-mail, je možn&eacute;, že server nie je spr&aacute;vne nakofigurovan&yacute; a mali by ste kontaktovať svojho administr&aacute;tora.';
$lang['install_admin_sitename'] = 'Toto je n&aacute;zov va&scaron;ej str&aacute;nky. Použ&iacute;va sa na r&ocirc;znych miestach prednastaven&yacute;ch &scaron;abl&oacute;n a pri použit&iacute; značky {sitename}.';
$lang['install_admin_db'] = 'Inform&aacute;cie odatab&aacute;ze';
$lang['install_admin_db_info'] = '<p>Overte si, či m&aacute;te vytvoren&uacute; datab&aacute;zu a už&iacute;vateľa, ktor&yacute; ma pr&iacute;stup k tejto datab&aacute;ze.</p>
<p>Pre MySQL použite nasleduj&uacute;ci postup:</p>
<p>Prihl&aacute;ste sa do MySQL z konzoly a zadajte nasleduj&uacute;ce pr&iacute;kazy:</p>
<ol>
<li>create database nazov_db; (n&aacute;zov db mus&iacute; byť bez medzier a diakritiky)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039; (kde cms_user je m&eacute;no už&iacute;vateľa a cms_pass je heslo)</li>
</ol>';
$lang['install_admin_follow'] = 'Pros&iacute;m vyplnte v&scaron;etky nasledovn&eacute; polia';
$lang['install_admin_db_type'] = 'Typ datab&aacute;zy';
$lang['install_admin_no_db'] = 'Va&scaron;a in&scaron;tal&aacute;cia PHP nebola skompilov&aacute;na s podporou datab&aacute;zov&yacute;ch ovl&aacute;dačov. Pros&iacute;m overte podporu pre in&scaron;tal&aacute;ciu mysql, mysqli, alebo postgres7 a a potom to skuste znova.';
$lang['install_admin_db_host'] = 'Adresa datab&aacute;zov&eacute;ho servera';
$lang['install_admin_db_name'] = 'N&aacute;zov datab&aacute;zy';
$lang['install_admin_db_create'] = 'Vytvoriť tabuľky (Varovanie: Odstr&aacute;ni existuj&uacute;ce d&aacute;ta)';
$lang['install_admin_db_prefix'] = 'Prefix tabuľky';
$lang['install_admin_db_sample'] = 'Nain&scaron;talovať aj vzorov&yacute; obsah a &scaron;abl&oacute;ny';
$lang['retry'] = 'Znova';
$lang['install_admin_db_create_seq'] = 'Vytv&aacute;ram tabuľku %s...';
$lang['install_admin_importing'] = 'Importujem vzorov&eacute; d&aacute;ta...';
$lang['invalid_query'] = 'Nespr&aacute;vny dotaz: %s';
$lang['install_creating_table'] = '<p>Vytv&aacute;ram tabulky %s... [%s]</p>';
$lang['install_creating_index'] = '<p>Vytv&aacute;ram index v tabulke %s ... [%s]</p>';
$lang['done'] = 'ok';
$lang['failed'] = 's chybou';
$lang['install_admin_error_schema'] = 'Chyba pri hľadan&iacute; SQL sch&eacute;my';
$lang['install_admin_set_account'] = 'Nastavujem administr&aacute;torsky &uacute;čet...';
$lang['install_admin_set_sitename'] = 'Nastavujem n&aacute;zov str&aacute;nok...';
$lang['install_admin_setup'] = 'Now let&#039;s continue to setup your configuration file, we already have most of the stuff we need. Chances are you can leave all these values alone, so when you are ready, click Continue.';
$lang['install_admin_docroot'] = 'CMS Document root (z pohľadu webservera)';
$lang['install_admin_docroot_path'] = 'Cesta k Document rootu';
$lang['install_admin_querystring'] = 'Retazec dotazu (v pr&iacute;pade probl&eacute;mov ponechajte toto pole pr&aacute;zdne, a nesk&ocirc;r modifikujte config.php)';
$lang['invalid_querys'] = '<b>Varovanie<b/>: Chybn&eacute; dotazy do va&scaron;ej DB!';
$lang['install_admin_sitedown'] = 'Chyba: Nie je možn&eacute; s&uacute;bor odstr&aacute;niť tmp/cache/SITEDOWN. Pros&iacute;m, odstr&aacute;nte ho ručne.';
$lang['install_admin_update_hierarchy'] = 'Aktualizujem poz&iacute;cie v hierarchii';
$lang['install_admin_set_core_event'] = 'Nastavujem udalosti...';
$lang['install_admin_install_modules'] = 'In&scaron;talujem moduly...';
$lang['install_admin_index_search'] = 'Indexujem pre vyhľad&aacute;vac&iacute; modul...';
$lang['install_admin_clear_cache'] = 'Premaz&aacute;vam ke&scaron; str&aacute;nok (ak existuje)...';
$lang['install_admin_emailing'] = 'Odosielam inform&aacute;cie o novom konte e-mailom...';
$lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;etko se nain&scaron;talovan=e - tu je va&scaron;e';
$lang['could_not_connect_db'] = 'Nepodarilo sa pripojiť k datab&aacute;zi. Skontrolujte pros&iacute;m pr&iacute;stupov&eacute; meno a heslo do datab&aacute;zy, a jeho opr&aacute;vnenia.';
$lang['cannot_write_config'] = 'Chyba: Nem&ocirc;žem zapisovať do %s.';
$lang['email_accountinfo_subject'] = 'Inform&aacute;cie o vytvorenom pr&iacute;stupe pre CMS Made Simple';
$lang['email_accountinfo_message'] = 'Ďakuje za nain&scaron;talovanie syst&eacute;mu CMS Made Simple.

Toto ja Va&scaron;e nov&eacute; už&iacute;vateľsk&eacute; konto:
už&iacute;vateľsk&eacute; meno: %s
heslo: %s

Prihl&aacute;ste sa pre administr&aacute;ciu str&aacute;nky: %s';
$lang['utma'] = '156861353.1064856217.1281704360.1298295362.1298881088.23';
$lang['utmz'] = '156861353.1298881088.23.25.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['qca'] = 'P0-799401210-1281704360909';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>